<?php

namespace Drupal\polaris\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Url;

/**
 * Form controller for the Polaris PIN forms.
 */
class PolarisPinResetForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'polaris_pin_reset';
  }

  /**
   * {@inheritdoc}
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   * @param string $library_card_number
   *   Library card number or Polaris username of user requesting reset.
   * @param string $expiration_date
   *   Formatted expiration date for the login link, or NULL if the link does
   *   not expire.
   * @param int $timestamp
   *   The current timestamp.
   * @param string $hash
   *   Login link hash.
   */
  public function buildForm(array $form, FormStateInterface $form_state, $library_card_number = NULL, $expiration_date = NULL, $timestamp = NULL, $hash = NULL) {
    if ($expiration_date) {
      $form['message'] = ['#markup' => $this->t('<p>This is a one-time login for %library_card_number and will expire on %expiration_date.</p><p>Click on this button to log in to the site and change your PIN.</p>', ['%library_card_number' => $library_card_number, '%expiration_date' => $expiration_date])];
      $form['#title'] = $this->t('Reset PIN');
    }
    else {
      // No expiration for first time login.
      $form['message'] = ['#markup' => $this->t('<p>This is a one-time login for %library_card_number.</p><p>Click on this button to log in to the site and change your PIN.</p>', ['%library_card_number' => $library_card_number])];
      $form['#title'] = $this->t('Set PIN');
    }

    $form['help'] = ['#markup' => '<p>' . $this->t('This login can be used only once.') . '</p>'];
    $form['actions'] = ['#type' => 'actions'];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Log in'),
    ];
    $form['#action'] = Url::fromRoute('polaris.reset.login', [
      'library_card_number' => $library_card_number,
      'timestamp' => $timestamp,
      'hash' => $hash,
    ])->toString();
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // This form works by submitting the hash and timestamp to the polaris.reset
    // route with a 'login' action.
  }

}
